@@ -1,9 +1,11 @@
-{% macro basic_load_csv_rows(model, batch_size, agate_table) %}
+{% macro clickhouse__load_csv_rows(model, agate_table) %}
   {% set cols_sql = get_seed_column_quoted_csv(model, agate_table.column_names) %}
+  {% set data_sql = adapter.get_csv_data(agate_table) %}
 
-  {% set sql %}
-      insert into {{ this.render() }} ({{ cols_sql }}) values
-  {% endset %}
+  {% set sql -%}
+      insert into {{ this.render() }} ({{ cols_sql }}) format CSV
+      {{ data_sql }}
+  {%- endset %}
 
   {% do adapter.add_query(sql, bindings=agate_table, abridge_sql_log=True) %}
 {% endmacro %}
@@ -23,7 +25,7 @@
     )
     {{ engine_clause(label='engine') }}
     {{ order_cols(label='order by') }}
-    {{ partition_cols(label='partitioned by') }}
+    {{ partition_cols(label='partition by') }}
   {% endset %}
 
   {% call statement('_') -%}
